# coding: utf-8

"""
    eBay Finances API

    This API is used to retrieve seller payouts and monetary transaction details related to those payouts.  # noqa: E501

    OpenAPI spec version: v1.15.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class OrderLineItem(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'fee_basis_amount': 'Amount',
        'line_item_id': 'str',
        'marketplace_fees': 'list[Fee]'
    }

    attribute_map = {
        'fee_basis_amount': 'feeBasisAmount',
        'line_item_id': 'lineItemId',
        'marketplace_fees': 'marketplaceFees'
    }

    def __init__(self, fee_basis_amount=None, line_item_id=None, marketplace_fees=None):  # noqa: E501
        """OrderLineItem - a model defined in Swagger"""  # noqa: E501
        self._fee_basis_amount = None
        self._line_item_id = None
        self._marketplace_fees = None
        self.discriminator = None
        if fee_basis_amount is not None:
            self.fee_basis_amount = fee_basis_amount
        if line_item_id is not None:
            self.line_item_id = line_item_id
        if marketplace_fees is not None:
            self.marketplace_fees = marketplace_fees

    @property
    def fee_basis_amount(self):
        """Gets the fee_basis_amount of this OrderLineItem.  # noqa: E501


        :return: The fee_basis_amount of this OrderLineItem.  # noqa: E501
        :rtype: Amount
        """
        return self._fee_basis_amount

    @fee_basis_amount.setter
    def fee_basis_amount(self, fee_basis_amount):
        """Sets the fee_basis_amount of this OrderLineItem.


        :param fee_basis_amount: The fee_basis_amount of this OrderLineItem.  # noqa: E501
        :type: Amount
        """

        self._fee_basis_amount = fee_basis_amount

    @property
    def line_item_id(self):
        """Gets the line_item_id of this OrderLineItem.  # noqa: E501

        The unique identifier of an order line item.  # noqa: E501

        :return: The line_item_id of this OrderLineItem.  # noqa: E501
        :rtype: str
        """
        return self._line_item_id

    @line_item_id.setter
    def line_item_id(self, line_item_id):
        """Sets the line_item_id of this OrderLineItem.

        The unique identifier of an order line item.  # noqa: E501

        :param line_item_id: The line_item_id of this OrderLineItem.  # noqa: E501
        :type: str
        """

        self._line_item_id = line_item_id

    @property
    def marketplace_fees(self):
        """Gets the marketplace_fees of this OrderLineItem.  # noqa: E501

        An array of all fees accrued for the order line item and deducted from a seller payout.  # noqa: E501

        :return: The marketplace_fees of this OrderLineItem.  # noqa: E501
        :rtype: list[Fee]
        """
        return self._marketplace_fees

    @marketplace_fees.setter
    def marketplace_fees(self, marketplace_fees):
        """Sets the marketplace_fees of this OrderLineItem.

        An array of all fees accrued for the order line item and deducted from a seller payout.  # noqa: E501

        :param marketplace_fees: The marketplace_fees of this OrderLineItem.  # noqa: E501
        :type: list[Fee]
        """

        self._marketplace_fees = marketplace_fees

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(OrderLineItem, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrderLineItem):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Buy Offer API

    <span class=\"tablenote\"><b>Note:</b> This is a <a href=\"https://developer.ebay.com/api-docs/static/versioning.html#limited\" target=\"_blank\"> <img src=\"/cms/img/docs/partners-api.svg\" class=\"legend-icon partners-icon\" title=\"Limited Release\"  alt=\"Limited Release\" />(Limited Release)</a> API available only to select developers approved by business units.</span><br /><br />The Buy Offer API enables Partners to place proxy bids for a buyer and retrieve the auctions where the buyer is bidding.  By placing a proxy bid, the buyer is agreeing to purchase the item if they win the auction. </p>   # noqa: E501

    OpenAPI spec version: v1_beta.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PlaceProxyBidRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'max_amount': 'Amount',
        'user_consent': 'UserConsent'
    }

    attribute_map = {
        'max_amount': 'maxAmount',
        'user_consent': 'userConsent'
    }

    def __init__(self, max_amount=None, user_consent=None):  # noqa: E501
        """PlaceProxyBidRequest - a model defined in Swagger"""  # noqa: E501
        self._max_amount = None
        self._user_consent = None
        self.discriminator = None
        if max_amount is not None:
            self.max_amount = max_amount
        if user_consent is not None:
            self.user_consent = user_consent

    @property
    def max_amount(self):
        """Gets the max_amount of this PlaceProxyBidRequest.  # noqa: E501


        :return: The max_amount of this PlaceProxyBidRequest.  # noqa: E501
        :rtype: Amount
        """
        return self._max_amount

    @max_amount.setter
    def max_amount(self, max_amount):
        """Sets the max_amount of this PlaceProxyBidRequest.


        :param max_amount: The max_amount of this PlaceProxyBidRequest.  # noqa: E501
        :type: Amount
        """

        self._max_amount = max_amount

    @property
    def user_consent(self):
        """Gets the user_consent of this PlaceProxyBidRequest.  # noqa: E501


        :return: The user_consent of this PlaceProxyBidRequest.  # noqa: E501
        :rtype: UserConsent
        """
        return self._user_consent

    @user_consent.setter
    def user_consent(self, user_consent):
        """Sets the user_consent of this PlaceProxyBidRequest.


        :param user_consent: The user_consent of this PlaceProxyBidRequest.  # noqa: E501
        :type: UserConsent
        """

        self._user_consent = user_consent

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PlaceProxyBidRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlaceProxyBidRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Fulfillment API

    Use the Fulfillment API to complete the process of packaging, addressing, handling, and shipping each order on behalf of the seller, in accordance with the payment method and timing specified at checkout.  # noqa: E501

    OpenAPI spec version: v1.19.18
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CancelStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cancel_requests': 'list[CancelRequest]',
        'cancel_state': 'str',
        'cancelled_date': 'str'
    }

    attribute_map = {
        'cancel_requests': 'cancelRequests',
        'cancel_state': 'cancelState',
        'cancelled_date': 'cancelledDate'
    }

    def __init__(self, cancel_requests=None, cancel_state=None, cancelled_date=None):  # noqa: E501
        """CancelStatus - a model defined in Swagger"""  # noqa: E501
        self._cancel_requests = None
        self._cancel_state = None
        self._cancelled_date = None
        self.discriminator = None
        if cancel_requests is not None:
            self.cancel_requests = cancel_requests
        if cancel_state is not None:
            self.cancel_state = cancel_state
        if cancelled_date is not None:
            self.cancelled_date = cancelled_date

    @property
    def cancel_requests(self):
        """Gets the cancel_requests of this CancelStatus.  # noqa: E501

        This array contains details of one or more buyer requests to cancel the order. <br /><br /><b>For the getOrders call:</b>  This array is returned but is always empty.<br /><b>For the getOrder call:</b> This array is returned fully populated with information about any cancellation requests.  # noqa: E501

        :return: The cancel_requests of this CancelStatus.  # noqa: E501
        :rtype: list[CancelRequest]
        """
        return self._cancel_requests

    @cancel_requests.setter
    def cancel_requests(self, cancel_requests):
        """Sets the cancel_requests of this CancelStatus.

        This array contains details of one or more buyer requests to cancel the order. <br /><br /><b>For the getOrders call:</b>  This array is returned but is always empty.<br /><b>For the getOrder call:</b> This array is returned fully populated with information about any cancellation requests.  # noqa: E501

        :param cancel_requests: The cancel_requests of this CancelStatus.  # noqa: E501
        :type: list[CancelRequest]
        """

        self._cancel_requests = cancel_requests

    @property
    def cancel_state(self):
        """Gets the cancel_state of this CancelStatus.  # noqa: E501

        The state of the order with regard to cancellation. This field is always returned, and if there are no cancellation requests, a value of <code>NONE_REQUESTED</code> is returned.  For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/fulfillment/types/sel:CancelStateEnum'>eBay API documentation</a>  # noqa: E501

        :return: The cancel_state of this CancelStatus.  # noqa: E501
        :rtype: str
        """
        return self._cancel_state

    @cancel_state.setter
    def cancel_state(self, cancel_state):
        """Sets the cancel_state of this CancelStatus.

        The state of the order with regard to cancellation. This field is always returned, and if there are no cancellation requests, a value of <code>NONE_REQUESTED</code> is returned.  For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/fulfillment/types/sel:CancelStateEnum'>eBay API documentation</a>  # noqa: E501

        :param cancel_state: The cancel_state of this CancelStatus.  # noqa: E501
        :type: str
        """

        self._cancel_state = cancel_state

    @property
    def cancelled_date(self):
        """Gets the cancelled_date of this CancelStatus.  # noqa: E501

        The date and time the order was cancelled, if applicable. This timestamp is in ISO 8601 format, which uses the 24-hour Universal Coordinated Time (UTC) clock. <br /><br /><b>Format:</b> <code>[YYYY]-[MM]-[DD]T[hh]:[mm]:[ss].[sss]Z</code> <br /><b>Example:</b> <code>2015-08-04T19:09:02.768Z</code>  # noqa: E501

        :return: The cancelled_date of this CancelStatus.  # noqa: E501
        :rtype: str
        """
        return self._cancelled_date

    @cancelled_date.setter
    def cancelled_date(self, cancelled_date):
        """Sets the cancelled_date of this CancelStatus.

        The date and time the order was cancelled, if applicable. This timestamp is in ISO 8601 format, which uses the 24-hour Universal Coordinated Time (UTC) clock. <br /><br /><b>Format:</b> <code>[YYYY]-[MM]-[DD]T[hh]:[mm]:[ss].[sss]Z</code> <br /><b>Example:</b> <code>2015-08-04T19:09:02.768Z</code>  # noqa: E501

        :param cancelled_date: The cancelled_date of this CancelStatus.  # noqa: E501
        :type: str
        """

        self._cancelled_date = cancelled_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CancelStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CancelStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Account API

    The <b>Account API</b> gives sellers the ability to configure their eBay seller accounts, including the seller's policies (eBay business policies and seller-defined custom policies), opt in and out of eBay seller programs, configure sales tax tables, and get account information.  <br/><br/>For details on the availability of the methods in this API, see <a href=\"/api-docs/sell/account/overview.html#requirements\">Account API requirements and restrictions</a>.  # noqa: E501

    OpenAPI spec version: v1.9.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CustomPolicyCreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'label': 'str',
        'name': 'str',
        'policy_type': 'str'
    }

    attribute_map = {
        'description': 'description',
        'label': 'label',
        'name': 'name',
        'policy_type': 'policyType'
    }

    def __init__(self, description=None, label=None, name=None, policy_type=None):  # noqa: E501
        """CustomPolicyCreateRequest - a model defined in Swagger"""  # noqa: E501
        self._description = None
        self._label = None
        self._name = None
        self._policy_type = None
        self.discriminator = None
        if description is not None:
            self.description = description
        if label is not None:
            self.label = label
        if name is not None:
            self.name = name
        if policy_type is not None:
            self.policy_type = policy_type

    @property
    def description(self):
        """Gets the description of this CustomPolicyCreateRequest.  # noqa: E501

        Details of the seller's specific policy and terms for this policy.<br/><br/><b>Max length:</b> 15,000  # noqa: E501

        :return: The description of this CustomPolicyCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CustomPolicyCreateRequest.

        Details of the seller's specific policy and terms for this policy.<br/><br/><b>Max length:</b> 15,000  # noqa: E501

        :param description: The description of this CustomPolicyCreateRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def label(self):
        """Gets the label of this CustomPolicyCreateRequest.  # noqa: E501

        Customer-facing label shown on View Item pages for items to which the policy applies. This seller-defined string is displayed as a system-generated hyperlink pointing to detailed policy information.<br/><br/><b>Max length:</b> 65  # noqa: E501

        :return: The label of this CustomPolicyCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        """Sets the label of this CustomPolicyCreateRequest.

        Customer-facing label shown on View Item pages for items to which the policy applies. This seller-defined string is displayed as a system-generated hyperlink pointing to detailed policy information.<br/><br/><b>Max length:</b> 65  # noqa: E501

        :param label: The label of this CustomPolicyCreateRequest.  # noqa: E501
        :type: str
        """

        self._label = label

    @property
    def name(self):
        """Gets the name of this CustomPolicyCreateRequest.  # noqa: E501

        The seller-defined name for the custom policy. Names must be unique for policies assigned to the same seller, policy type, and eBay marketplace.<br /><span class=\"tablenote\"><strong>Note:</strong> This field is visible only to the seller. </span><br/><br/><b>Max length:</b> 65  # noqa: E501

        :return: The name of this CustomPolicyCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CustomPolicyCreateRequest.

        The seller-defined name for the custom policy. Names must be unique for policies assigned to the same seller, policy type, and eBay marketplace.<br /><span class=\"tablenote\"><strong>Note:</strong> This field is visible only to the seller. </span><br/><br/><b>Max length:</b> 65  # noqa: E501

        :param name: The name of this CustomPolicyCreateRequest.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def policy_type(self):
        """Gets the policy_type of this CustomPolicyCreateRequest.  # noqa: E501

        Specifies the type of custom policy being created. <br/><br/>Two Custom Policy types are supported: <ul><li>Product Compliance (PRODUCT_COMPLIANCE)</li> <li>Takeback (TAKE_BACK)</li></ul> For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/account/types/api:CustomPolicyTypeEnum'>eBay API documentation</a>  # noqa: E501

        :return: The policy_type of this CustomPolicyCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._policy_type

    @policy_type.setter
    def policy_type(self, policy_type):
        """Sets the policy_type of this CustomPolicyCreateRequest.

        Specifies the type of custom policy being created. <br/><br/>Two Custom Policy types are supported: <ul><li>Product Compliance (PRODUCT_COMPLIANCE)</li> <li>Takeback (TAKE_BACK)</li></ul> For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/account/types/api:CustomPolicyTypeEnum'>eBay API documentation</a>  # noqa: E501

        :param policy_type: The policy_type of this CustomPolicyCreateRequest.  # noqa: E501
        :type: str
        """

        self._policy_type = policy_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CustomPolicyCreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomPolicyCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Logistics API

    <span class=\"tablenote\"><b>Note:</b> This is a <a href=\"https://developer.ebay.com/api-docs/static/versioning.html#limited\" target=\"_blank\"> <img src=\"/cms/img/docs/partners-api.svg\" class=\"legend-icon partners-icon\" title=\"Limited Release\"  alt=\"Limited Release\" />(Limited Release)</a> API available only to select developers approved by business units.</span><br /><br />The <b>Logistics API</b> resources offer the following capabilities: <ul><li><b>shipping_quote</b> &ndash; Consolidates into a list a set of live shipping rates, or quotes, from which you can select a rate to ship a package.</li> <li><b>shipment</b> &ndash; Creates a \"shipment\" for the selected shipping rate.</li></ul> Call <b>createShippingQuote</b> to get a list of live shipping rates. The rates returned are all valid for a specific time window and all quoted prices are at eBay-negotiated rates. <br><br>Select one of the live rates and using its associated <b>rateId</b>, create a \"shipment\" for the package by calling <b>createFromShippingQuote</b>. Creating a shipment completes an agreement, and the cost of the base service and any added shipping options are summed into the returned <b>totalShippingCost</b> value. This action also generates a shipping label that you can use to ship the package.  The total cost of the shipment is incurred when the package is shipped using the supplied shipping label.  <p class=\"tablenote\"><b>Important!</b> Sellers must set up a payment method via their eBay account before they can use the methods in this API to create a shipment and the associated shipping label.</p>  # noqa: E501

    OpenAPI spec version: v1_beta.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Contact(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'company_name': 'str',
        'contact_address': 'ContactAddress',
        'full_name': 'str',
        'primary_phone': 'PhoneNumber'
    }

    attribute_map = {
        'company_name': 'companyName',
        'contact_address': 'contactAddress',
        'full_name': 'fullName',
        'primary_phone': 'primaryPhone'
    }

    def __init__(self, company_name=None, contact_address=None, full_name=None, primary_phone=None):  # noqa: E501
        """Contact - a model defined in Swagger"""  # noqa: E501
        self._company_name = None
        self._contact_address = None
        self._full_name = None
        self._primary_phone = None
        self.discriminator = None
        if company_name is not None:
            self.company_name = company_name
        if contact_address is not None:
            self.contact_address = contact_address
        if full_name is not None:
            self.full_name = full_name
        if primary_phone is not None:
            self.primary_phone = primary_phone

    @property
    def company_name(self):
        """Gets the company_name of this Contact.  # noqa: E501

        The company name with which the contact is associated.  # noqa: E501

        :return: The company_name of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """Sets the company_name of this Contact.

        The company name with which the contact is associated.  # noqa: E501

        :param company_name: The company_name of this Contact.  # noqa: E501
        :type: str
        """

        self._company_name = company_name

    @property
    def contact_address(self):
        """Gets the contact_address of this Contact.  # noqa: E501


        :return: The contact_address of this Contact.  # noqa: E501
        :rtype: ContactAddress
        """
        return self._contact_address

    @contact_address.setter
    def contact_address(self, contact_address):
        """Sets the contact_address of this Contact.


        :param contact_address: The contact_address of this Contact.  # noqa: E501
        :type: ContactAddress
        """

        self._contact_address = contact_address

    @property
    def full_name(self):
        """Gets the full_name of this Contact.  # noqa: E501

        The contact's full name.  # noqa: E501

        :return: The full_name of this Contact.  # noqa: E501
        :rtype: str
        """
        return self._full_name

    @full_name.setter
    def full_name(self, full_name):
        """Sets the full_name of this Contact.

        The contact's full name.  # noqa: E501

        :param full_name: The full_name of this Contact.  # noqa: E501
        :type: str
        """

        self._full_name = full_name

    @property
    def primary_phone(self):
        """Gets the primary_phone of this Contact.  # noqa: E501


        :return: The primary_phone of this Contact.  # noqa: E501
        :rtype: PhoneNumber
        """
        return self._primary_phone

    @primary_phone.setter
    def primary_phone(self, primary_phone):
        """Sets the primary_phone of this Contact.


        :param primary_phone: The primary_phone of this Contact.  # noqa: E501
        :type: PhoneNumber
        """

        self._primary_phone = primary_phone

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Contact, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Contact):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
